@@ -27,25 +27,27 @@ library(DALEX)
 titanic_imputed_cut <- titanic_imputed[1:100,]
 apartments_cut <- apartments[1:100,]
 
-test_that("randomForest", {
-  library(randomForest)
+#:# removed due to the randomForest requirement for R v4.1
 
-  model_classif_rf <- randomForest(as.factor(survived)~., data = titanic_imputed_cut, num.trees = 50, probability = TRUE)
-  model_regr_rf <- randomForest(m2.price~., data = apartments_cut, num.trees = 50)
-
-  explainer_classif_rf <- explain(model_classif_rf, data = titanic_imputed_cut, y = titanic_imputed_cut$survived, verbose = FALSE)
-  explainer_classif_rf_pos <- explain(model_classif_rf, data = titanic_imputed_cut, y = titanic_imputed_cut$survived, verbose = FALSE, predict_function_target_column = 1)
-  explainer_regr_rf <- explain(model_regr_rf, data = apartments_cut, y = apartments_cut$m2.price, verbose = FALSE)
-  expect_is(explainer_classif_rf$y_hat, "numeric")
-  expect_is(explainer_classif_rf_pos$y_hat, "numeric")
-  expect_false(all(explainer_classif_rf_pos$y_hat == explainer_classif_rf$y_hat))
-  expect_is(explainer_classif_rf$model_info, "model_info")
-  expect_is(explainer_regr_rf$y_hat, "numeric")
-  expect_is(explainer_regr_rf$model_info, "model_info")
-  expect_length(DALEX:::yhat.randomForest(model_classif_rf, titanic_imputed_cut[1,]), 1)
-  expect_length(DALEX:::yhat.randomForest(model_regr_rf, apartments_cut[1,]), 1)
-
-})
+# test_that("randomForest", {
+#   library(randomForest)
+#
+#   model_classif_rf <- randomForest(as.factor(survived)~., data = titanic_imputed_cut, num.trees = 50, probability = TRUE)
+#   model_regr_rf <- randomForest(m2.price~., data = apartments_cut, num.trees = 50)
+#
+#   explainer_classif_rf <- explain(model_classif_rf, data = titanic_imputed_cut, y = titanic_imputed_cut$survived, verbose = FALSE)
+#   explainer_classif_rf_pos <- explain(model_classif_rf, data = titanic_imputed_cut, y = titanic_imputed_cut$survived, verbose = FALSE, predict_function_target_column = 1)
+#   explainer_regr_rf <- explain(model_regr_rf, data = apartments_cut, y = apartments_cut$m2.price, verbose = FALSE)
+#   expect_is(explainer_classif_rf$y_hat, "numeric")
+#   expect_is(explainer_classif_rf_pos$y_hat, "numeric")
+#   expect_false(all(explainer_classif_rf_pos$y_hat == explainer_classif_rf$y_hat))
+#   expect_is(explainer_classif_rf$model_info, "model_info")
+#   expect_is(explainer_regr_rf$y_hat, "numeric")
+#   expect_is(explainer_regr_rf$model_info, "model_info")
+#   expect_length(DALEX:::yhat.randomForest(model_classif_rf, titanic_imputed_cut[1,]), 1)
+#   expect_length(DALEX:::yhat.randomForest(model_regr_rf, apartments_cut[1,]), 1)
+#
+# })
 
 test_that("svm", {
   library(e1071)
@@ -158,13 +160,22 @@ test_that("parsnip", {
 
 })
 
+
 test_that("caret", {
 
   library(caret)
 
-  caret_regr <- train(m2.price~., data = apartments_cut, method="rf", ntree = 50)
+  caret_regr <- train(m2.price~., data = apartments_cut, method="ranger", num.trees = 50)
   caret_regr_lm <- train(m2.price~., data = apartments_cut, method="lm")
-  caret_classif <- train(as.factor(survived)~., data = titanic_imputed_cut, method="rf", ntree = 50)
+
+  train_titanic_imputed_cut <- titanic_imputed_cut
+  train_titanic_imputed_cut$survived <- ifelse(train_titanic_imputed_cut$survived == 1, "yes", "no")
+  caret_classif <- train(
+    x = train_titanic_imputed_cut,
+    y = train_titanic_imputed_cut$survived,
+    method="ranger",
+    trControl = trainControl(classProbs = TRUE)
+  )
 
   explainer_classif_caret <- explain(caret_classif, data = titanic_imputed_cut, y = titanic_imputed_cut$survived, verbose = FALSE)
   explainer_classif_caret_pos <- explain(caret_classif, data = titanic_imputed_cut, y = titanic_imputed_cut$survived, verbose = FALSE, predict_function_target_column = 1)
