@@ -1,11 +1,13 @@
 context("Check predict_parts() function")
 
 new_apartments <- apartments_test[1001, -1]
+new_apartments_set <- apartments_test[999:1001, -1]
 
 test_that("data not provided",{
   expect_error(predict_parts(explainer_wo_data, type = "break_down"))
   expect_error(predict_parts(explainer_wo_data, type = "break_down_interactions"))
   expect_error(predict_parts(explainer_wo_data, type = "shap"))
+  expect_error(predict_parts(explainer_wo_data, type = "shap_aggregated"))
 })
 
 test_that("wrong type value",{
@@ -16,6 +18,7 @@ test_that("Wrong object class (not explainer)", {
   expect_error(predict_parts(list(1), type = "break_down"))
   expect_error(predict_parts(list(1), type = "break_down_interactions"))
   expect_error(predict_parts(list(1), type = "shap"))
+  expect_error(predict_parts(explainer_wo_data, type = "shap_aggregated"))
 })
 
 test_that("Output format",{
@@ -26,6 +29,10 @@ test_that("Output format",{
   pp_ranger_ibreak_down <- predict_parts(explainer_regr_ranger, new_observation = new_apartments, type = "break_down_interactions")
   pp_lm_shap <- predict_parts(explainer_regr_lm, new_observation = new_apartments, type = "shap")
   pp_ranger_shap <- predict_parts(explainer_regr_ranger, new_observation = new_apartments, type = "shap")
+  pp_lm_agg_shap <- predict_parts(explainer_regr_lm, new_observation = new_apartments, type = "shap_aggregated")
+  pp_ranger_agg_shap <- predict_parts(explainer_regr_ranger, new_observation = new_apartments, type = "shap_aggregated")
+  pp_lm_agg_shap_set <- predict_parts(explainer_regr_lm, new_observation = new_apartments_set, type = "shap_aggregated")
+  pp_ranger_agg_shap_set <- predict_parts(explainer_regr_ranger, new_observation = new_apartments_set, type = "shap_aggregated")
 
   pp_lm_osc <- predict_parts(explainer_regr_lm, new_observation = new_apartments, type = "oscillations")
   pp_ranger_osc <- predict_parts(explainer_regr_ranger, new_observation = new_apartments, type = "oscillations")
@@ -41,6 +48,10 @@ test_that("Output format",{
   expect_is(pp_ranger_ibreak_down, c("break_down", 'predict_parts'))
   expect_is(pp_lm_shap, c("shap", 'predict_parts'))
   expect_is(pp_ranger_shap, c("shap", 'predict_parts'))
+  expect_is(pp_lm_agg_shap, c("shap_aggregated", 'predict_parts'))
+  expect_is(pp_ranger_agg_shap, c("shap_aggregated", 'predict_parts'))
+  expect_is(pp_lm_agg_shap_set, c("shap_aggregated", 'predict_parts'))
+  expect_is(pp_ranger_agg_shap_set, c("shap_aggregated", 'predict_parts'))
   expect_is(pp_lm_osc, c("oscillations", 'predict_parts'))
   expect_is(pp_ranger_osc, c("oscillations", 'predict_parts'))
   expect_is(pp_lm_osc_uni, c("oscillations_uni", 'predict_parts'))
@@ -56,6 +67,10 @@ test_that("Output format - plot",{
   pp_ranger_ibreak_down <- predict_parts(explainer_regr_ranger, new_observation = new_apartments, type = "break_down_interactions")
   pp_lm_shap <- predict_parts(explainer_regr_lm, new_observation = new_apartments, type = "shap")
   pp_ranger_shap <- predict_parts(explainer_regr_ranger, new_observation = new_apartments, type = "shap")
+  pp_lm_agg_shap <- predict_parts(explainer_regr_lm, new_observation = new_apartments, type = "shap_aggregated")
+  pp_ranger_agg_shap <- predict_parts(explainer_regr_ranger, new_observation = new_apartments, type = "shap_aggregated")
+  pp_lm_agg_shap_set <- predict_parts(explainer_regr_lm, new_observation = new_apartments_set, type = "shap_aggregated")
+  pp_ranger_agg_shap_set <- predict_parts(explainer_regr_ranger, new_observation = new_apartments_set, type = "shap_aggregated")
 
   pp_lm_osc <- predict_parts(explainer_regr_lm, new_observation = new_apartments, type = "oscillations")
   pp_ranger_osc <- predict_parts(explainer_regr_ranger, new_observation = new_apartments, type = "oscillations")
@@ -70,6 +85,10 @@ test_that("Output format - plot",{
   expect_is(plot(pp_ranger_ibreak_down, pp_lm_ibreak_down), "gg")
   expect_is(plot(pp_ranger_shap), "gg")
   expect_is(plot(pp_ranger_shap, pp_lm_shap), "gg")
+  expect_is(plot(pp_lm_agg_shap), "gg")
+  expect_is(plot(pp_ranger_agg_shap), "gg")
+  expect_is(plot(pp_lm_agg_shap_set), "gg")
+  expect_is(plot(pp_ranger_agg_shap_set), "gg")
   expect_is(plot(pp_lm_osc), "gg")
   expect_is(plot(pp_ranger_osc), "gg")
   expect_is(plot(pp_lm_osc_uni), "gg")
@@ -87,6 +106,10 @@ test_that("Output format",{
   va_ranger_ibreak_down <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "break_down_interactions")
   va_lm_shap <- variable_attribution(explainer_regr_lm, new_observation = new_apartments, type = "shap")
   va_ranger_shap <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "shap")
+  va_lm_agg_shap <- variable_attribution(explainer_regr_lm, new_observation = new_apartments, type = "shap_aggregated")
+  va_ranger_agg_shap <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "shap_aggregated")
+  va_lm_agg_shap_set <- variable_attribution(explainer_regr_lm, new_observation = new_apartments_set, type = "shap_aggregated")
+  va_ranger_agg_shap_set <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments_set, type = "shap_aggregated")
 
   expect_is(va_lm_break_down, c("break_down", 'predict_parts'))
   expect_is(va_ranger_break_down, c("break_down", 'predict_parts'))
@@ -94,6 +117,10 @@ test_that("Output format",{
   expect_is(va_ranger_ibreak_down, c("break_down", 'predict_parts'))
   expect_is(va_lm_shap, c("shap", 'predict_parts'))
   expect_is(va_ranger_shap, c("shap", 'predict_parts'))
+  expect_is(va_lm_agg_shap, c("shap_aggregated", 'predict_parts'))
+  expect_is(va_ranger_agg_shap, c("shap_aggregated", 'predict_parts'))
+  expect_is(va_lm_agg_shap_set, c("shap_aggregated", 'predict_parts'))
+  expect_is(va_ranger_agg_shap_set, c("shap_aggregated", 'predict_parts'))
 })
 
 test_that("Output format - plot",{
@@ -103,6 +130,10 @@ test_that("Output format - plot",{
   va_ranger_ibreak_down <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "break_down_interactions")
   va_lm_shap <- variable_attribution(explainer_regr_lm, new_observation = new_apartments, type = "shap")
   va_ranger_shap <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "shap")
+  va_lm_agg_shap <- variable_attribution(explainer_regr_lm, new_observation = new_apartments, type = "shap_aggregated")
+  va_ranger_agg_shap <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "shap_aggregated")
+  va_lm_agg_shap_set <- variable_attribution(explainer_regr_lm, new_observation = new_apartments_set, type = "shap_aggregated")
+  va_ranger_agg_shap_set <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments_set, type = "shap_aggregated")
 
   expect_is(plot(va_ranger_break_down), "gg")
   expect_is(plot(va_ranger_break_down, va_lm_break_down), "gg")
@@ -110,6 +141,10 @@ test_that("Output format - plot",{
   expect_is(plot(va_ranger_ibreak_down, va_lm_ibreak_down), "gg")
   expect_is(plot(va_ranger_shap), "gg")
   expect_is(plot(va_ranger_shap, va_lm_shap), "gg")
+  expect_is(plot(va_lm_agg_shap), "gg")
+  expect_is(plot(va_ranger_agg_shap), "gg")
+  expect_is(plot(va_lm_agg_shap_set), "gg")
+  expect_is(plot(va_ranger_agg_shap_set), "gg")
 })
 
 test_that("Output format - plot with subset",{
@@ -119,6 +154,10 @@ test_that("Output format - plot with subset",{
   va_ranger_ibreak_down <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "break_down_interactions", N = 200)
   va_lm_shap <- variable_attribution(explainer_regr_lm, new_observation = new_apartments, type = "shap", N = 200)
   va_ranger_shap <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "shap", N = 200)
+  va_lm_agg_shap <- variable_attribution(explainer_regr_lm, new_observation = new_apartments, type = "shap_aggregated", N=200)
+  va_ranger_agg_shap <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments, type = "shap_aggregated", N=200)
+  va_lm_agg_shap_set <- variable_attribution(explainer_regr_lm, new_observation = new_apartments_set, type = "shap_aggregated", N=200)
+  va_ranger_agg_shap_set <- variable_attribution(explainer_regr_ranger, new_observation = new_apartments_set, type = "shap_aggregated", N=200)
 
   expect_is(plot(va_ranger_break_down), "gg")
   expect_is(plot(va_ranger_break_down, va_lm_break_down), "gg")
@@ -126,4 +165,8 @@ test_that("Output format - plot with subset",{
   expect_is(plot(va_ranger_ibreak_down, va_lm_ibreak_down), "gg")
   expect_is(plot(va_ranger_shap), "gg")
   expect_is(plot(va_ranger_shap, va_lm_shap), "gg")
+  expect_is(plot(va_lm_agg_shap), "gg")
+  expect_is(plot(va_ranger_agg_shap), "gg")
+  expect_is(plot(va_lm_agg_shap_set), "gg")
+  expect_is(plot(va_ranger_agg_shap_set), "gg")
 })
